import { db } from "@/server/db";
import fs from "fs";
import path from "path";

try {
  // Try to use the SQLite migrator if available
  const { migrate } = require("drizzle-orm/better-sqlite3/migrator");
  console.log("Using SQLite migrator...");
  migrate(db, { migrationsFolder: "./drizzle" });
  console.log("SQLite migration completed successfully.");
} catch (error) {
  console.warn("SQLite migration failed:", error.message);
  console.warn("Attempting JSON database initialization...");
  
  try {
    // Ensure JSON DB file exists
    const jsonDbPath = process.env.DB_JSON_PATH || "/app/db/db.json";
    const jsonDir = path.dirname(jsonDbPath);
    
    if (!fs.existsSync(jsonDir)) {
      fs.mkdirSync(jsonDir, { recursive: true });
    }
    
    if (!fs.existsSync(jsonDbPath)) {
      // Initialize with empty schema
      const emptyDb = {};
      fs.writeFileSync(jsonDbPath, JSON.stringify(emptyDb, null, 2));
      console.log("Created empty JSON database structure at", jsonDbPath);
    } else {
      console.log("JSON database file already exists at", jsonDbPath);
    }
  } catch (jsonError) {
    console.error("Failed to initialize JSON database:", jsonError);
    throw new Error("Cannot initialize any database system");
  }
}
